==> breeze_website_builder_5.4.55.tar.gz: manage/generate_site_map_shell.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	11/28/2013	ELL
// Modified: 9/5/2014	ELL
// Added Generate Site Map button.
// 

	include ("check_session.php");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Admin Function Select</title>
<link rel="stylesheet" href="manager.css" type="text/css">
<style type="text/css">
#generate_site_map_heading	{	width:260px;	}
#help_button	{	
	position:relative;
	display:block;
	top:-15px;
	left:220px;
	height:31px;
	width:31px;
	z-index:100;
}
</style>

<script language="javascript" type="text/javascript">
function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#sitemap", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}
</script>
</head>

<body>
<div id="sub_level_1_buttons">
	<div class="button_heading_sub_level_1" id="generate_site_map_heading"><div class="button_heading_text_sub_level_1">Generate Site Map</div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
    
    <p>Generating site map...</p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
<?php
	include("generate_site_map.php");
	echo "<p>" . $msg . "</p>\n";
?>
</div>
</body>
</html>

==> breeze_website_builder_6.1.20.tar.gz: manage/generate_site_map_shell.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	11/28/2013	ELL
// Modified: 9/5/2014	ELL
// Added Generate Site Map button.
// 

	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Admin Function Select | Breeze Website Builder</title>
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<style type="text/css">
#generate_site_map_heading	{	width:260px;	}
#help_button	{	
	position:relative;
	display:block;
	top:-15px;
	left:220px;
	height:31px;
	width:31px;
	z-index:100;
}
</style>

<script language="javascript" type="text/javascript">
window.parent.document.title = document.title;

function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#sitemap", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}
</script>
</head>

<body>
<div id="sub_level_1_buttons">
	<div class="button_heading_sub_level_1" id="generate_site_map_heading"><div class="button_heading_text_sub_level_1"><?php echo GENERATE_SITE_MAP_HEADING; ?></div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
    
    <p><?php echo GENERATE_SITE_MAP_GENERATING; ?></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
    <p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>.</b></p>
<?php
	include("generate_site_map.php");
	echo "<p>" . $msg . "</p>\n";
?>
</div>
</body>
</html>
